<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://scoutech.com.br
 * @since      1.2.0
 *
 * @package    ScoutSportsBR
 * @subpackage ScoutSportsBR/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    ScoutSportsBR
 * @subpackage ScoutSportsBR/admin
 * @author     Julian Romero <jromero@swim.com.br>
 */
class ScoutSportsBR_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;
	public $default_values;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Plugin_Name_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Plugin_Name_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/scoutsportsbr-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Plugin_Name_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Plugin_Name_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/scoutsportsbr-admin.js', array( 'jquery' ), $this->version, false );

	}

	public function add_plugin_admin_menu() {

		/*
		 * Add a settings page for this plugin to the Settings menu.
		 *
		 * NOTE:  Alternative menu locations are available via WordPress administration menu functions.
		 *
		 *        Administration Menus: http://codex.wordpress.org/Administration_Menus
		 *
		 */
		add_options_page( 'Scout Sports', 'Scout Sports', 'manage_options', $this->plugin_name, array($this, 'display_plugin_setup_page') );
	}

	 /**
	 * Add settings action link to the plugins page.
	 *
	 * @since    1.0.0
	 */

	public function add_action_links( $links ) {
		/*
		*  Documentation : https://codex.wordpress.org/Plugin_API/Filter_Reference/plugin_action_links_(plugin_file_name)
		*/
	   $settings_link = array(
		'<a href="' . admin_url( 'options-general.php?page=' . $this->plugin_name ) . '">' . __('Settings', $this->plugin_name) . '</a>',
	   );
	   return array_merge(  $settings_link, $links );

	}

	/**
	 * Render the settings page for this plugin.
	 *
	 * @since    1.0.0
	 */

	public function display_plugin_setup_page() {
		include_once( 'partials/scoutsportsbr-admin-display.php' );
	}

	/**
	 * validar dados da configuração da tabela
	**/

	public function validate($input) {
		$valid = array();

		//Cleanup
/*
		$valid['id-campeonato'] = (isset($input['id-campeonato']) && !empty($input['id-campeonato'])) ? $input['id-campeonato'] : 0;
		$valid['exibir-artilharia-ranking'] = (isset($input['exibir-artilharia-ranking']) && !empty($input['exibir-artilharia-ranking'])) ? 1 : 0;
		$valid['exibir-artilharia-gols'] = (isset($input['exibir-artilharia-gols']) && !empty($input['exibir-artilharia-gols'])) ? 1 : 0;
		$valid['exibir-artilharia-equipe'] = (isset($input['exibir-artilharia-equipe']) && !empty($input['exibir-artilharia-equipe'])) ? 1 : 0;
		$valid['exibir-artilharia-foto-equipe'] = (isset($input['exibir-artilharia-foto-equipe']) && !empty($input['exibir-artilharia-foto-equipe'])) ? 1 : 0;
		$valid['exibir-artilharia-atleta'] = (isset($input['exibir-artilharia-atleta']) && !empty($input['exibir-artilharia-atleta'])) ? 1 : 0;
		$valid['exibir-artilharia-foto-atleta'] = (isset($input['exibir-artilharia-foto-atleta']) && !empty($input['exibir-artilharia-foto-atleta'])) ? 1 : 0;
//		$valid['chave-acesso'] = sanitize_text_field($input['chave-acesso']);
*/

		return $valid;
	 }

	/**
	 * registrar as opções no wordpress
	**/

	 public function options_update() {
		register_setting($this->plugin_name, $this->plugin_name, array($this, 'validate'));
	 }


}
