<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://scoutech.com.br
 * @since      1.17
 *
 * @package    ScoutSportsBR
 * @subpackage ScoutSportsBR/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    ScoutSportsBR
 * @subpackage ScoutSportsBR/public
 * @author     Julian Romero <jromero@swim.com.br>
 */
class ScoutSportsBR_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Plugin_Name_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Plugin_Name_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/scoutsportsbr-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.10
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Plugin_Name_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Plugin_Name_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/scoutsportsbr-public.js', array( 'jquery' ), $this->version, false );

	}

	/**
	 * transformar o shortcode na tabela apropriada
	**/

	public function scoutsportsbr_register_shortcodes(){

		function scoutsportsbr_shortcode($atts){
			$options = get_option('scoutsportsbr');
			$atributos = shortcode_atts( array(
				'css' => $options['css'],
				'id-campeonato' => $options['id-campeonato'],
				'exibir-artilharia-ranking' => $options['exibir-artilharia-ranking'],
				'exibir-artilharia-atleta' => $options['exibir-artilharia-atleta'],
				'exibir-artilharia-foto-atleta' => $options['exibir-artilharia-foto-atleta'],
				'exibir-artilharia-equipe' => $options['exibir-artilharia-equipe'],
				'exibir-artilharia-foto-equipe' => $options['exibir-artilharia-foto-equipe'],
				'exibir-artilharia-gols' => $options['exibir-artilharia-gols'],
				'exibir-estatistica-total-jogos' => $options['exibir-estatistica-total-jogos'],
				'exibir-estatistica-total-gols' => $options['exibir-estatistica-total-gols'],
				'exibir-estatistica-media-gols' => $options['exibir-estatistica-media-gols'],
				'exibir-estatistica-total-assistencias' => $options['exibir-estatistica-total-assistencias'],
				'exibir-estatistica-total-ca' => $options['exibir-estatistica-total-ca'],
				'exibir-estatistica-total-cv' => $options['exibir-estatistica-total-cv'],
				'exibir-estatistica-total-wo' => $options['exibir-estatistica-total-wo'],
				'exibir-estatistica-total-derrotas' => $options['exibir-estatistica-total-derrotas'],
				'exibir-estatistica-total-vitorias' => $options['exibir-estatistica-total-vitorias'],
				'exibir-estatistica-total-empates' => $options['exibir-estatistica-total-empates'],
				'exibir-estatistica-total-jogos' => $options['exibir-estatistica-total-jogos'],
				'exibir-estatistica-foto-jogador' => $options['exibir-estatistica-foto-jogador'],
				'exibir-estatistica-logo-equipe' => $options['exibir-estatistica-logo-equipe'],
				'exibir-estatistica-nome-jogador' => $options['exibir-estatistica-nome-jogador'],
				'exibir-estatistica-nome-equipe' => $options['exibir-estatistica-nome-equipe'],
				'exibir-ranking-nome-equipe' => $options['exibir-ranking-nome-equipe'],
				'exibir-ranking-foto-jogador' => $options['exibir-ranking-foto-jogador'],
				'exibir-ranking-logo-equipe' => $options['exibir-ranking-logo-equipe'],
				'exibir-ranking-numero-jogos' => $options['exibir-ranking-numero-jogos'],
				'exibir-ranking' => $options['exibir-ranking'],
				'exibir-ranking-total' => $options['exibir-ranking-total'],
				'exibir-ranking-nome-jogador' => $options['exibir-ranking-nome-jogador'],
				'exibir-categorias' => $options['exibir-categorias'],
				'exibir-equipe' => $options['exibir-equipe'],
				'exibir-sigla' => $options['exibir-sigla'],
				'ocorrencia' => $options['ocorrencia'],
				'ranking' => $options['ranking'],
				'jogo' => $options['jogo'],
				'sede' => $options['sede'],
				'grupo' => $options['grupo'],
				'fase' => $options['fase'],
				'equipe' => $options['equipe'],
				'reduzido' => $options['reduzido'],
				'sem-titulo' => $options['sem-titulo'],
				'periodo' => $options['periodo'],
				'categoria' => $options['categoria'],
				'limite' => $options['limite'],
				'modelo' => $options['modelo'] ?? '',
				'sem-ranking' => $options['sem-ranking'],
			), $atts, 'scoutsportsbr' );
			$options_query = http_build_query ($atributos);
			$xy=rand(0,99999);
			$htm='<div id="scoutsportsbr-tabela-exibicao-'.$xy.'"></div>';
			$htm.='<script>
			var div_tabela'.$xy.' = "#scoutsportsbr-tabela-exibicao-'.$xy.'";
			function scoutsportsbr_removeLoader(){
			    jQuery( "#scoutsportsbr-loadingDiv" ).fadeOut(500, function() {
			      jQuery( "#scoutsportsbr-loadingDiv" ).remove();
			  });
			}
			if (typeof jQuery == "undefined") {
				alert("jQuery não está carregado, ele é essencial para o funcionamento da tabela...");
			} else {
				jQuery.ajax({
					beforeSend: function() {
						jQuery("#scoutsportsbr-tabela-exibicao-'.$xy.'").append(\'<div style="min-height:250px; width:100%;" id="scoutsportsbr-loadingDiv"><div class="scoutsportsbr-loader">Loading...</div></div>\');
					},
					url: "https://scoutech.com.br/webservice/index.php?",
					data: "'.$atts[0].'&'.$options_query.'",
					error: function() {
						jQuery(div_tabela).html("<h2>Não foi possível gerar a tabela solicitada. <a href=mailto:jromero@swim.com.br>Comunique o programador</a>.</h2>");
					},
					dataType: "html",
					success: function(data) {
						jQuery(div_tabela'.$xy.').html(data);
					},
					complete: function() {
					  setTimeout(scoutsportsbr_removeLoader, 2000);
					},
					type: "GET"
				});

			}
			</script>';
			return $htm;
      }

      add_shortcode("scoutsportsbr", "scoutsportsbr_shortcode");

    }


}
